@@ -16,17 +16,19 @@
 
 import sys
 import re
-import time
 import calendar
 import math
 from collections import defaultdict
 from . import wcwidth
 from .displaying import colorme, FormattedValue, DEFAULT_VALUE_COLORS
 from cassandra.cqltypes import EMPTY
+from cassandra.util import datetime_from_timestamp
+from util import UTC
 
 unicode_controlchars_re = re.compile(r'[\x00-\x31\x7f-\xa0]')
 controlchars_re = re.compile(r'[\x00-\x31\x7f-\xff]')
 
+
 def _show_control_chars(match):
     txt = repr(match.group(0))
     if txt.startswith('u'):
@@ -37,6 +39,7 @@ def _show_control_chars(match):
 
 bits_to_turn_red_re = re.compile(r'\\([^uUx]|u[0-9a-fA-F]{4}|x[0-9a-fA-F]{2}|U[0-9a-fA-F]{8})')
 
+
 def _make_turn_bits_red_f(color1, color2):
     def _turn_bits_red(match):
         txt = match.group(0)
@@ -51,6 +54,7 @@ default_float_precision = 3
 default_colormap = DEFAULT_VALUE_COLORS
 empty_colormap = defaultdict(lambda: '')
 
+
 def format_by_type(cqltype, val, encoding, colormap=None, addcolor=False,
                    nullval=None, time_format=None, float_precision=None):
     if nullval is None:
@@ -69,6 +73,7 @@ def format_by_type(cqltype, val, encoding, colormap=None, addcolor=False,
                         time_format=time_format, float_precision=float_precision,
                         nullval=nullval)
 
+
 def color_text(bval, colormap, displaywidth=None):
     # note that here, we render natural backslashes as just backslashes,
     # in the same color as surrounding text, when using color. When not
@@ -87,6 +92,7 @@ def color_text(bval, colormap, displaywidth=None):
         displaywidth -= bval.count(r'\\')
     return FormattedValue(bval, coloredval, displaywidth)
 
+
 def format_value_default(val, colormap, **_):
     val = str(val)
     escapedval = val.replace('\\', '\\\\')
@@ -97,18 +103,21 @@ def format_value_default(val, colormap, **_):
 # making format_value a generic function
 _formatters = {}
 
+
 def format_value(type, val, **kwargs):
     if val == EMPTY:
         return format_value_default('', **kwargs)
     formatter = _formatters.get(type.__name__, format_value_default)
     return formatter(val, **kwargs)
 
+
 def formatter_for(typname):
     def registrator(f):
         _formatters[typname] = f
         return f
     return registrator
 
+
 @formatter_for('bytearray')
 def format_value_blob(val, colormap, **_):
     bval = '0x' + ''.join('%02x' % c for c in val)
@@ -122,10 +131,12 @@ def format_python_formatted_type(val, colormap, color, quote=False):
         bval = "'%s'" % bval
     return colorme(bval, colormap, color)
 
+
 @formatter_for('Decimal')
 def format_value_decimal(val, colormap, **_):
     return format_python_formatted_type(val, colormap, 'decimal')
 
+
 @formatter_for('UUID')
 def format_value_uuid(val, colormap, **_):
     return format_python_formatted_type(val, colormap, 'uuid')
@@ -135,17 +146,19 @@ def format_value_uuid(val, colormap, **_):
 def formatter_value_inet(val, colormap, quote=False, **_):
     return format_python_formatted_type(val, colormap, 'inet', quote=quote)
 
+
 @formatter_for('bool')
 def format_value_boolean(val, colormap, **_):
     return format_python_formatted_type(val, colormap, 'boolean')
 
+
 def format_floating_point_type(val, colormap, float_precision, **_):
     if math.isnan(val):
         bval = 'NaN'
     elif math.isinf(val):
         bval = 'Infinity'
     else:
-        exponent = int(math.log10(abs(val))) if abs(val) > sys.float_info.epsilon else -sys.maxint -1
+        exponent = int(math.log10(abs(val))) if abs(val) > sys.float_info.epsilon else -sys.maxint - 1
         if -4 <= exponent < float_precision:
             # when this is true %g will not use scientific notation,
             # increasing precision should not change this decision
@@ -157,6 +170,7 @@ def format_floating_point_type(val, colormap, float_precision, **_):
 
 formatter_for('float')(format_floating_point_type)
 
+
 def format_integer_type(val, colormap, **_):
     # base-10 only for now; support others?
     bval = str(val)
@@ -165,6 +179,7 @@ def format_integer_type(val, colormap, **_):
 formatter_for('long')(format_integer_type)
 formatter_for('int')(format_integer_type)
 
+
 @formatter_for('date')
 def format_value_timestamp(val, colormap, time_format, quote=False, **_):
     bval = strftime(time_format, calendar.timegm(val.utctimetuple()))
@@ -174,22 +189,11 @@ def format_value_timestamp(val, colormap, time_format, quote=False, **_):
 
 formatter_for('datetime')(format_value_timestamp)
 
+
 def strftime(time_format, seconds):
-    local = time.localtime(seconds)
-    formatted = time.strftime(time_format, local)
-    if local.tm_isdst != 0:
-        offset = -time.altzone
-    else:
-        offset = -time.timezone
-    if formatted[-4:] != '0000' or time_format[-2:] != '%z' or offset == 0:
-        return formatted
-    # deal with %z on platforms where it isn't supported. see CASSANDRA-4746.
-    if offset < 0:
-        sign = '-'
-    else:
-        sign = '+'
-    hours, minutes = divmod(abs(offset) / 60, 60)
-    return formatted[:-5] + sign + '{0:0=2}{1:0=2}'.format(hours, minutes)
+    tzless_dt = datetime_from_timestamp(seconds)
+    return tzless_dt.replace(tzinfo=UTC()).strftime(time_format)
+
 
 @formatter_for('str')
 def format_value_text(val, encoding, colormap, quote=False, **_):
@@ -206,6 +210,7 @@ def format_value_text(val, encoding, colormap, quote=False, **_):
 # name alias
 formatter_for('unicode')(format_value_text)
 
+
 def format_simple_collection(val, lbracket, rbracket, encoding,
                              colormap, time_format, float_precision, nullval):
     subs = [format_value(type(sval), sval, encoding=encoding, colormap=colormap,
@@ -219,16 +224,19 @@ def format_simple_collection(val, lbracket, rbracket, encoding,
     displaywidth = 2 * len(subs) + sum(sval.displaywidth for sval in subs)
     return FormattedValue(bval, coloredval, displaywidth)
 
+
 @formatter_for('list')
 def format_value_list(val, encoding, colormap, time_format, float_precision, nullval, **_):
     return format_simple_collection(val, '[', ']', encoding, colormap,
                                     time_format, float_precision, nullval)
 
+
 @formatter_for('tuple')
 def format_value_tuple(val, encoding, colormap, time_format, float_precision, nullval, **_):
     return format_simple_collection(val, '(', ')', encoding, colormap,
                                     time_format, float_precision, nullval)
 
+
 @formatter_for('set')
 def format_value_set(val, encoding, colormap, time_format, float_precision, nullval, **_):
     return format_simple_collection(sorted(val), '{', '}', encoding, colormap,
@@ -249,8 +257,8 @@ def format_value_map(val, encoding, colormap, time_format, float_precision, null
     lb, comma, colon, rb = [colormap['collection'] + s + colormap['reset']
                             for s in ('{', ', ', ': ', '}')]
     coloredval = lb \
-               + comma.join(k.coloredval + colon + v.coloredval for (k, v) in subs) \
-               + rb
+        + comma.join(k.coloredval + colon + v.coloredval for (k, v) in subs) \
+        + rb
     displaywidth = 4 * len(subs) + sum(k.displaywidth + v.displaywidth for (k, v) in subs)
     return FormattedValue(bval, coloredval, displaywidth)
 formatter_for('OrderedDict')(format_value_map)
@@ -274,7 +282,7 @@ def format_value_utype(val, encoding, colormap, time_format, float_precision, nu
     lb, comma, colon, rb = [colormap['collection'] + s + colormap['reset']
                             for s in ('{', ', ', ': ', '}')]
     coloredval = lb \
-                 + comma.join(k.coloredval + colon + v.coloredval for (k, v) in subs) \
-                 + rb
+        + comma.join(k.coloredval + colon + v.coloredval for (k, v) in subs) \
+        + rb
     displaywidth = 4 * len(subs) + sum(k.displaywidth + v.displaywidth for (k, v) in subs)
     return FormattedValue(bval, coloredval, displaywidth)
